#!/bin/bash

MYRETURNCODE=0
PROGRAMDIR=$(cd "$(dirname $0)" && pwd)

. "${PROGRAMDIR}/conf/backup-rsync-remote.conf"

MACADDRESS=$(sed -r 's/( |\t)+/ /g;s/^ //g;s/;//g' /etc/dhcp/dhcpd.conf|grep -v ^#|grep -v ^$|grep -A1 "^host ${REMOTE_SHORTNAME}"|tail -1|cut -d' ' -f3)


# Démarrage du host par wakeonlan
/usr/bin/wakeonlan ${MACADDRESS} >/dev/null 2>&1

# Attente du démarrage complet - 60 secondes doivent suffire
sleep 60

##############################
##### ERREURS BLOQUANTES #####
##############################

# Vérification du host up & running 
ping -c1 "${REMOTE_HOST}" 2>/dev/null 1>&2
if [ "$?" != "0" ] ; then
	sleep 120
	ping -c1 "${REMOTE_HOST}" 2>/dev/null 1>&2
	if [ "$?" != "0" ] ; then
		echo "Error: Unable to ping host ${REMOTE_HOST} - Aborded" >&2
		exit 1
	fi
fi

# Envoi de la clé de chiffrement
scp -i "${CERTIFICATE_KEY_FILE}" "${PROGRAMDIR}/${LUKS_KEY_FILE}" "${REMOTE_USER}@${REMOTE_HOST}:${REMOTE_KEYFILE}" >/dev/null
RETURNCODE=$?
if [ "${RETURNCODE}" != "0" ] ; then
	echo "Error: Sending LUKS key file ended with exit code ${RETURNCODE} - Aborded" >&2
	exit 2
fi

# Ouverture du container LUKS
ssh -i "${CERTIFICATE_KEY_FILE}" "${REMOTE_USER}@${REMOTE_HOST}" "cryptsetup -d ${REMOTE_KEYFILE} -l ${REMOTE_KEYLENGTH} luksOpen ${REMOTE_CONTAINER} ${REMOTE_LUKSNAME}"
RETURNCODE=$?
if [ "${RETURNCODE}" != "0" ] ; then
	echo "Error: Opening LUKS container ended with exit code ${RETURNCODE} - Aborded" >&2
	exit 3
fi

# Suppression immédiate de la clé
ssh -i "${CERTIFICATE_KEY_FILE}" "${REMOTE_USER}@${REMOTE_HOST}" "srm ${REMOTE_KEYFILE}"
RETURNCODE=$?
if [ "${RETURNCODE}" != "0" ] ; then
	echo "Warning: Removing LUKS key file ended with exit code ${RETURNCODE}" >&2
fi

# Vérification de l'intégrité filesystem avant montage
ssh -i "${CERTIFICATE_KEY_FILE}" "${REMOTE_USER}@${REMOTE_HOST}" "e2fsck -p /dev/mapper/${REMOTE_LUKSNAME}"
RETURNCODE=$?
if [ "${RETURNCODE}" != "0" ] ; then
	echo "Warning: Filesystem consistency check ended with exit code ${RETURNCODE}" >&2
fi

# Montage du répertoire
ssh -i "${CERTIFICATE_KEY_FILE}" "${REMOTE_USER}@${REMOTE_HOST}" "mount ${REMOTE_MOUNT}"
RETURNCODE=$?
if [ "${RETURNCODE}" != "0" ] ; then
        echo "Error: Mounting ${REMOTE_MOUNT} ended with exit code ${RETURNCODE} - Aborded" >&2
        exit 4
fi

echo "Remote server ready!"
exit ${MYRETURNCODE}

